/* Written by Mark Zealey (mark@zealos.org) 2002 to see if there was a bug in
 * libvorbisfile or not.. Do what you want with it.
 */

#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include <unistd.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <dirent.h>
#include "vorbis/codec.h"
#include "vorbis/vorbisfile.h"

double print_time(char *name)
{
	OggVorbis_File vf;
	FILE *file;
	double time;

	printf("%s: ", name);

	file = fopen(name, "r");

	if(ov_open(file, &vf, NULL, 0) < 0) {
		printf("Not an ogg file?\n");
		return 0;
	}

	time = ov_time_total(&vf, -1);
	printf("%.2f seconds\n", time);

	ov_clear(&vf);

	return time;
}

double traverse_dir(char *n)
{
	DIR *dir;
	struct dirent *t;
	char buf[300];			/* Bad, bad, bad... */
	char name[300];
	double total = 0;

	strcpy(name, n);
	if(name[strlen(name) - 1] != '/')
		strcat(name, "/");

	dir = opendir(name);

	if(!dir) {
		printf("%s: Can't open dir\n", name);
		return;
	}

	while(t = readdir(dir)) {
		char *cur = t->d_name;
		struct stat m;

		if(cur[0] == '.')
			continue;

		strcpy(buf, name);
		strcat(buf, cur);

		if(stat(buf, &m) != 0) {
			printf("%s: Unknown error with stat()\n", buf);
			continue;
		}

		if(S_ISDIR(m.st_mode))
			total += traverse_dir(buf);
		else
			total += print_time(buf);
	}

	closedir(dir);

	printf("%s: %.2f seconds\n", n, total);

	return total;
}

int main(int argc, char **argv)
{
	int i = 1;

	if(argc == 1)
		traverse_dir(".");

	while(i < argc)
		traverse_dir(argv[i++]);

	return 0;
}
